@@ -1,5 +1,5 @@
 """Just utilities made by Jim Vogel"""
-
+import itertools
 from collections import namedtuple
 from datetime import datetime
 from functools import wraps
@@ -9,7 +9,7 @@ from loguru import logger
 import pytz
 import requests
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 
 def logged_user(func):
@@ -45,6 +45,15 @@ def now_utc():
     return datetime.now(pytz.utc).replace(second=0, microsecond=0, tzinfo=None)
 
 
+def chunked(iterable, size):
+    it = iter(iterable)
+    while True:
+        chunk = tuple(itertools.islice(it, size))
+        if not chunk:
+            break
+        yield chunk
+
+
 def add_key_from_id(data: Iterable[dict]):
     for row in data:
         row["key"] = row["id"]
